<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Sie sind dabei, alle Unterzeichner dieser Petition zu löschen. Sind Sie sicher?',
	'aucune_signature' => 'Keine Unterzeicher',

	// B
	'bouton_checkbox_envoi_message' => 'Möglichkeit zum Senden von Nachrichten',
	'bouton_checkbox_indiquer_site' => 'Angabe einer Website erforderlich',
	'bouton_checkbox_signature_unique_email' => 'eine einzige Unterzeichnung pro Email',
	'bouton_checkbox_signature_unique_site' => 'nur ein Unterzeichner pro Website',
	'bouton_radio_activer_petition' => 'Petitionen aktivieren',
	'bouton_radio_pas_petition' => 'Keine Petition',
	'bouton_radio_petition_activee' => 'Petition aktiviert',
	'bouton_radio_supprimer_petition' => 'Petition löschen',

	// F
	'filtre' => 'Filter:',
	'form_pet_adresse_site' => 'Adresse (URL) Ihrer Website',
	'form_pet_aucune_signature' => 'Diesem Code entspricht keine Signatur...',
	'form_pet_confirmation' => 'Bitte bestätigen Sie Ihre Unterschrift:',
	'form_pet_deja_signe' => 'Sie haben diesen Text bereits unterschrieben.',
	'form_pet_envoi_mail_confirmation' => 'Eine E-mail wurde zur Prüfung Ihrer Identität an @email@ geschickt. Sie müssen die dort angegebene WWW-Seite öffnen, um Ihre Unterschrift zu bestätigen.',
	'form_pet_mail_confirmation' => 'Hallo,

Sie möchten diese Petition unterzeichnen:
@titre@.

Sie haben die folgenden Angaben gemacht:
    Name: @nom_email@
    Website: @nom_site@ - @url_site@
    @message@

ACHTUNG:
Um Ihre Unterschrift zu bestätigen müssen Sie diese Seite aufrufen (wenn Sie es nicht tun, wird Ihre Unterschrift verworfen):

    @url@


Vielen Dank für Ihre Teilnahme
',
	'form_pet_message_commentaire' => 'Eine Nachricht oder ein Kommentar?',
	'form_pet_nom_site2' => 'Name Ihrer Website',
	'form_pet_probleme_liens' => 'Bitte entfernen Sie die Hyperlinks aus Ihrer Nachricht.',
	'form_pet_probleme_technique' => 'Technisches Problem: Signaturen sind vorübergehend nicht möglich.',
	'form_pet_signature_validee' => 'Ihre Signatur wurde erfolgreich geprüft. Vielen Dank!',
	'form_pet_site_deja_enregistre' => 'Diese Website wurde bereits erfasst',
	'form_pet_url_invalide' => 'Sie haben einen ungültigen URL angegeben.',
	'form_pet_votre_email' => 'Ihre E-Mail Adresse',
	'form_pet_votre_nom' => 'Ihr Name',
	'form_pet_votre_site' => 'Wenn Sie eine eigene Website haben, können Sie sie hier eintragen',

	// I
	'icone_relancer_signataire' => 'Unterzeichner neu initialisieren',
	'icone_relancer_signataires' => 'Die Unterzeichner neu initialisieren',
	'icone_suivi_petitions' => 'Petitionen verwalten/verfolgen',
	'icone_supprimer_signature' => 'Diese Unterschrift löschen',
	'icone_supprimer_signatures' => 'Unterzeichner löschen',
	'icone_valider_signature' => 'Unterzeichnung bestätigen',
	'icone_valider_signatures' => 'Unterzeichner bestätigen',
	'info_adresse_email' => 'E-MAIL ADRESSE:',
	'info_fonctionnement_petition' => 'Funktionsweise der Petition:',
	'info_signature_supprimee' => 'Unterschrift gelöscht',
	'info_signature_supprimee_erreur' => 'Fehler: Dieser Löschcode entspricht keiner Unterschrift.',
	'info_site_web' => 'WEBSITE:',
	'info_texte_message' => 'Text Ihrer Nachricht:',

	// L
	'lien_reponse_article' => 'Antwort auf Artikel',

	// N
	'nombre_signatures' => '@nb@ Unterzeichner',

	// S
	'sans_nom' => 'Anonym',
	'signatures_article' => 'Unterzeichner des Artikels:',
	'signatures_aucune' => 'Kein',
	'signatures_meme_auteur' => 'Unterschriften des gleichen Unterzeichners',
	'signatures_meme_site' => 'Unterzeichner der gleichen Website',
	'signatures_poubelle' => 'Gelöscht',
	'signatures_prop' => 'In der Warteschlange',
	'signatures_publie' => 'Bestätigt',
	'signatures_recherche_label' => 'Unterzeichner suchen:',
	'signatures_selection' => 'Unterschriften auswählen:',
	'signatures_toutes' => 'Alle',
	'statut_poubelle' => 'Gelöscht',
	'statut_prop' => 'Warten auf Freischaltung',
	'statut_publie' => 'Bestätigt',

	// T
	'texte_descriptif_petition' => 'Beschreibung der Petition',
	'titre_page_controle_petition' => 'Verfolgen der Petitionen',
	'titre_petition' => 'Petition',
	'titre_petitions' => 'Petitionen',
	'titre_selection_action' => 'Auswahl',
	'titre_signatures_attente' => 'Warteschlange der Unterzeichner',
	'titre_signatures_publie' => 'Bestätigte Unterzeichner',
	'titre_suivi_petition' => 'Petitionen verfolgen',
	'tout_voir' => 'Alle Unterzeichner anzeigen',

	// U
	'une_signature' => '1 Unterzeichner',

	// V
	'voir_signatures_objet' => 'Unterzeichner Anzeigen '
);

?>
